DEFAULT_FILE="./ymm.yml"
import yaml
import os,shutil
from .ymm import YMM

def load_file(yaml_file=DEFAULT_FILE):
    print("Loading "+yaml_file)
    with open(yaml_file) as data:
        raw_yaml = yaml.full_load(data)
        return YMM(raw_yaml)

def run_file(yaml_file=DEFAULT_FILE):
    ymm = from_file(name, spark, folder)
    return ymm.run()



import re
import argparse
import pkg_resources
from pathlib import Path
from .file import *

__version__ = pkg_resources.require("ymm")[0].version

parser = argparse.ArgumentParser(description='Run actions.')
parser.add_argument('actions', metavar='action', nargs='*',
                    help='actions from ymm.yaml to execute')
parser.add_argument('-f','--file', default=DEFAULT_FILE,
                    help='YAML file of actions')
parser.add_argument('-d','--debug', action='store_true',
                    help='print debugging information')
parser.add_argument('-v','--version', action='version',
                    version=f'%(prog)s {__version__}')

def add_versions(ctx):
    try:
        local_version = Path('version.txt').read_text().strip()
    except e:
        print(e)
        return ctx
    digits = re.findall(r'\d+', local_version)
    last = int(digits[-1])
    devNext = local_version.replace(f'dev{last}',f'dev{last+1}')
    ctx['__version__'] = local_version
    ctx['__version_digits__'] = digits
    ctx['__version_next__'] = devNext
    return ctx

def context(args):
    ctx = add_versions(dict(os.environ))
    for arg in vars(args):
        value = getattr(args, arg)
        ctx[arg] = getattr(args, arg)
    return ctx

def main():
    args = parser.parse_args()
    file = args.file
    ymm = load_file(file)
    ymm.env = context(args)
    if 'debug' in ymm.env: print(ymm.env['__version__'])
    actions = args.actions
    for action in actions:
        ymm.log(f'; {action}')
        results = ymm.run(action)

#main()



#!/usr/bin/env python3
import pytest
from .context import *

FIRST_KEY='install'

@pytest.fixture
def y():
    return ymm.load_file(TEST_FILE)

def test_load(y):
    assert y
    assert y.yaml
    assert y.yaml[FIRST_KEY]

def test_run(y):
    result = y.run(FIRST_KEY)
    assert FIRST_KEY in result[0]



import subprocess

class YMM:
    def __init__(self, yaml, debug=True):
        self.yaml = yaml
        self.env = {}

    def run(self,arg=False):
        actions = self.yaml[arg]
        results = [self.execute(cmd) for cmd in actions]
        return results

    def execute(self, cmd):
        sub = cmd.format(**self.env)
        args = sub.split(" ")
        self.log(args)
        result = subprocess.run(args, stdout=subprocess.PIPE)
        msg = result.stdout.decode("utf-8")
        print(f'# {msg}')
        return msg.strip()

    def log(self, arg):
        if 'debug' in self.env: print(f'YMM.log {arg}')
